import React from 'react';
import PropTypes from 'prop-types';

import './stepper.css';

/**
 * Creates a stepper.
 * @param {array} steps - Names of different steps.
 * @param {number} activeStep - Index of the active step.
 * @param {string} className - Classname of the component.
 * @param {string} styleComponent - Style of the component.
 * @param {string} styleStep - Style of the step box.
 * @param {string} styleLine - Style of the line between step boxes.
 * @returns {ReactElement} - Stepper generated
 */
var Stepper = function Stepper(_ref) {
  var steps = _ref.steps,
      activeStep = _ref.activeStep,
      className = _ref.className,
      styleComponent = _ref.styleComponent,
      styleStep = _ref.styleStep,
      styleLine = _ref.styleLine;

  var stepsLines = steps.reduce(function (r, a) {
    return r.concat(a, false);
  }, []);
  stepsLines.pop();
  return React.createElement(
    'div',
    { style: styleComponent, className: 'Stepper ' + className },
    stepsLines.map(function (step, i) {
      return i % 2 ? React.createElement('div', {
        key: i,
        style: styleLine,
        className: 'Stepper-line ' + (++activeStep >= i ? 'Stepper-activeStep' : '')
      }) : React.createElement(
        'div',
        {
          key: i,
          style: styleStep,
          className: 'Stepper-step ' + (activeStep >= i ? 'Stepper-activeStep' : '')
        },
        step
      );
    })
  );
};

Stepper.propTypes = process.env.NODE_ENV !== "production" ? {
  // State
  steps: PropTypes.arrayOf(PropTypes.string).isRequired,
  activeStep: PropTypes.number.isRequired,

  // Modifiers
  className: PropTypes.string,
  style: PropTypes.object,
  styleStep: PropTypes.object,
  styleLine: PropTypes.object
} : {};

Stepper.defaultProps = {
  // Modifiers
  className: '',
  style: {},
  styleStep: {},
  styleLine: {}
};

export default Stepper;